==> nmrium-0.49.0.tgz: package/lib/component/panels/RangesPanel/RangesHeader.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { SvgNmrIntegrate, SvgNmrSum } from 'cheminfo-font';
import lodashGet from 'lodash/get';
import { rangesToACS } from 'nmr-processing';
import { FaFileExport, FaUnlink, FaSitemap, FaChartBar } from 'react-icons/fa';
import { ImLink } from 'react-icons/im';
import { ClipboardFallbackModal } from '../../../utils/clipboard/clipboardComponents';
import { useClipboard } from '../../../utils/clipboard/clipboardHooks';
import { useAssignmentData } from '../../assignment/AssignmentsContext';
import { useDispatch } from '../../context/DispatchContext';
import ActiveButton from '../../elements/ActiveButton';
import Button from '../../elements/ButtonToolTip';
import { useAlert } from '../../elements/popup/Alert';
import { useModal } from '../../elements/popup/Modal';
import { useActiveSpectrumRangesViewState } from '../../hooks/useActiveSpectrumRangesViewState';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import CopyClipboardModal from '../../modal/CopyClipboardModal';
import ChangeSumModal from '../../modal/changeSum/ChangeSumModal';
import { PeaksToggleActions } from '../PeaksPanel/PeaksToggleActions';
import DefaultPanelHeader, { createFilterLabel, } from '../header/DefaultPanelHeader';
const style = css `
  .btn {
    background-color: transparent;
    border: none;
  }

  .icon svg {
    font-size: 12px;
  }

  .preview-publication-icon svg {
    font-size: 13px;
  }

  button {
    margin-right: 2px;
  }
`;
function RangesHeader({ ranges, info, onUnlink, onFilterActivated, onSettingClick, isFilterActive, filterCounter, activeTab, }) {
    const dispatch = useDispatch();
    const modal = useModal();
    const alert = useAlert();
    const assignmentData = useAssignmentData();
    const currentSum = lodashGet(ranges, 'options.sum', null);
    const rangesPreferences = usePanelPreferences('ranges', activeTab);
    const { showMultiplicityTrees, showJGraph, showIntegrals, showIntegralsValues, showPeaks, displayingMode, } = useActiveSpectrumRangesViewState();
    function changeRangesSumHandler(options) {
        dispatch({ type: 'CHANGE_RANGE_SUM', payload: { options } });
        modal.close();
    }
    function removeAssignments() {
        onUnlink();
    }
    function handleOnRemoveAssignments() {
        modal.showConfirmDialog({
            message: 'All assignments will be removed. Are you sure?',
            buttons: [{ text: 'Yes', handler: removeAssignments }, { text: 'No' }],
        });
    }
    function handleDeleteAll() {
        modal.showConfirmDialog({
            message: 'All ranges will be deleted. Are You sure?',
            buttons: [
                {
                    text: 'Yes',
                    handler: () => {
                        dispatch({
                            type: 'DELETE_RANGE',
                            payload: { assignmentData },
                        });
                    },
                },
                { text: 'No' },
            ],
        });
    }
    function handleSetShowMultiplicityTrees() {
        dispatch({
            type: 'TOGGLE_RANGES_VIEW_PROPERTY',
            payload: { key: 'showMultiplicityTrees' },
        });
    }
    function handleShowIntegralsValues() {
        dispatch({
            type: 'TOGGLE_RANGES_VIEW_PROPERTY',
            payload: { key: 'showIntegralsValues' },
        });
    }
    function handleShowIntegrals() {
        dispatch({
            type: 'TOGGLE_RANGES_VIEW_PROPERTY',
            payload: { key: 'showIntegrals' },
        });
    }
    function handleShowJGraph() {
        dispatch({
            type: 'TOGGLE_RANGES_VIEW_PROPERTY',
            payload: { key: 'showJGraph' },
        });
    }
    const { rawWriteWithType, shouldFallback, cleanShouldFallback, text } = useClipboard();
    function saveToClipboardHandler(value) {
        void rawWriteWithType(value, 'text/html').then(() => alert.success('Data copied to clipboard'));
    }
    function saveAsHTMLHandler() {
        if (Array.isArray(ranges?.values) && ranges.values.length > 0) {
            const { originFrequency: observedFrequency, nucleus } = info;
            const result = rangesToACS(ranges.values, {
                nucleus, // '19f'
                deltaFormat: rangesPreferences.deltaPPM.format,
                couplingFormat: rangesPreferences.coupling.format,
                observedFrequency, //400
            });
            modal.show(_jsx(CopyClipboardModal, { text: result, onCopyClick: saveToClipboardHandler, onClose: () => modal.close() }), {});
        }
    }
    function changeSumConstantFlagHandler() {
        dispatch({
            type: 'CHANGE_RANGES_SUM_FLAG',
        });
    }
    function toggleViewProperty(key) {
        dispatch({ type: 'TOGGLE_RANGES_VIEW_PROPERTY', payload: { key } });
    }
    function toggleDisplayingMode() {
        dispatch({ type: 'TOGGLE_RANGES_PEAKS_DISPLAYING_MODE' });
    }
    const hasRanges = Array.isArray(ranges?.values) && ranges.values.length > 0;
    const counter = ranges?.values?.length || 0;
    return (_jsxs("div", { css: style, children: [_jsxs(DefaultPanelHeader, { counter: counter, counterLabel: createFilterLabel(counter, isFilterActive && filterCounter), onDelete: handleDeleteAll, deleteToolTip: "Delete All Ranges", onFilter: onFilterActivated, filterToolTip: isFilterActive ? 'Show all ranges' : 'Hide ranges out of view', showSettingButton: true, onSettingClick: onSettingClick, children: [_jsx(Button, { popupTitle: "Preview publication string", popupPlacement: "right", onClick: saveAsHTMLHandler, className: "btn preview-publication-icon", disabled: !hasRanges, children: _jsx(FaFileExport, {}) }), _jsx(ChangeSumModal, { onSave: changeRangesSumHandler, sumType: "ranges", currentSum: currentSum, sumOptions: ranges?.options, renderButton: (onClick) => (_jsx(Button, { popupTitle: currentSum
                                ? `Change ranges sum (${currentSum.toFixed(2)})`
                                : 'Change ranges sum', popupPlacement: "right", className: "btn icon", onClick: onClick, children: _jsx(SvgNmrSum, {}) })) }), _jsx(Button, { popupTitle: "Remove all assignments", popupPlacement: "right", onClick: handleOnRemoveAssignments, disabled: !hasRanges, className: "btn icon", children: _jsx(FaUnlink, {}) }), _jsx(ActiveButton, { popupTitle: showMultiplicityTrees
                            ? 'Hide multiplicity trees in spectrum'
                            : 'Show multiplicity trees in spectrum', popupPlacement: "right", onClick: handleSetShowMultiplicityTrees, value: showMultiplicityTrees, disabled: !hasRanges, children: _jsx(FaSitemap, { style: { pointerEvents: 'none', fontSize: '12px' } }) }), _jsx(ActiveButton, { popupTitle: showJGraph ? 'Hide J Graph' : 'Show J Graph', popupPlacement: "right", onClick: handleShowJGraph, value: showJGraph, disabled: !hasRanges, children: _jsx(FaChartBar, { style: { pointerEvents: 'none', fontSize: '12px' } }) }), _jsx(ActiveButton, { popupTitle: showIntegrals ? 'Hide integrals' : 'Show integrals', popupPlacement: "right", onClick: handleShowIntegrals, value: showIntegrals, disabled: !hasRanges, children: _jsx(SvgNmrIntegrate, { style: { pointerEvents: 'none', fontSize: '12px' } }) }), _jsx(ActiveButton, { popupTitle: showIntegralsValues
                            ? 'Hide integrals values'
                            : 'Show integrals values', popupPlacement: "right", onClick: handleShowIntegralsValues, value: showIntegralsValues, disabled: !hasRanges, children: _jsx(SvgNmrIntegrate, { style: { pointerEvents: 'none', fontSize: '12px' } }) }), _jsx(ActiveButton, { className: "icon", popupTitle: "Fixed integration sum", popupPlacement: "right", onClick: changeSumConstantFlagHandler, value: ranges?.options?.isSumConstant, children: _jsx(ImLink, {}) }), _jsx(PeaksToggleActions, { disbale: !hasRanges, showPeaks: showPeaks, onShowToggle: () => toggleViewProperty('showPeaks'), displayingMode: displayingMode, onDisplayingModeToggle: toggleDisplayingMode })] }), _jsx(ClipboardFallbackModal, { mode: shouldFallback, onDismiss: cleanShouldFallback, text: text, label: "Preview publication string" })] }));
}
export default RangesHeader;

==> nmrium-0.50.0.tgz: package/lib/component/panels/RangesPanel/RangesHeader.js <==
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { SvgNmrIntegrate } from 'cheminfo-font';
import lodashGet from 'lodash/get';
import { rangesToACS } from 'nmr-processing';
import { FaFileExport, FaUnlink, FaSitemap, FaChartBar } from 'react-icons/fa';
import { ImLink } from 'react-icons/im';
import { Toolbar } from 'react-science/ui';
import { ClipboardFallbackModal } from '../../../utils/clipboard/clipboardComponents';
import { useClipboard } from '../../../utils/clipboard/clipboardHooks';
import { useAssignmentData } from '../../assignment/AssignmentsContext';
import { useDispatch } from '../../context/DispatchContext';
import { useAlert } from '../../elements/popup/Alert';
import { useModal } from '../../elements/popup/Modal';
import { useActiveSpectrumRangesViewState } from '../../hooks/useActiveSpectrumRangesViewState';
import { usePanelPreferences } from '../../hooks/usePanelPreferences';
import CopyClipboardModal from '../../modal/CopyClipboardModal';
import ChangeSumModal from '../../modal/changeSum/ChangeSumModal';
import { PeaksToggleActions } from '../PeaksPanel/PeaksToggleActions';
import DefaultPanelHeader, { createFilterLabel, } from '../header/DefaultPanelHeader';
function RangesHeader({ ranges, info, onUnlink, onFilterActivated, onSettingClick, isFilterActive, filterCounter, activeTab, }) {
    const dispatch = useDispatch();
    const modal = useModal();
    const alert = useAlert();
    const assignmentData = useAssignmentData();
    const currentSum = lodashGet(ranges, 'options.sum', null);
    const rangesPreferences = usePanelPreferences('ranges', activeTab);
    const { showMultiplicityTrees, showJGraph, showIntegrals, showIntegralsValues, showPeaks, displayingMode, } = useActiveSpectrumRangesViewState();
    function changeRangesSumHandler(options) {
        dispatch({ type: 'CHANGE_RANGE_SUM', payload: { options } });
        modal.close();
    }
    function removeAssignments() {
        onUnlink();
    }
    function handleOnRemoveAssignments() {
        modal.showConfirmDialog({
            message: 'All assignments will be removed. Are you sure?',
            buttons: [{ text: 'Yes', handler: removeAssignments }, { text: 'No' }],
        });
    }
    function handleDeleteAll() {
        modal.showConfirmDialog({
            message: 'All ranges will be deleted. Are You sure?',
            buttons: [
                {
                    text: 'Yes',
                    handler: () => {
                        dispatch({
                            type: 'DELETE_RANGE',
                            payload: { assignmentData },
                        });
                    },
                },
                { text: 'No' },
            ],
        });
    }
    function handleSetShowMultiplicityTrees() {
        dispatch({
            type: 'TOGGLE_RANGES_VIEW_PROPERTY',
            payload: { key: 'showMultiplicityTrees' },
        });
    }
    function handleShowIntegralsValues() {
        dispatch({
            type: 'TOGGLE_RANGES_VIEW_PROPERTY',
            payload: { key: 'showIntegralsValues' },
        });
    }
    function handleShowIntegrals() {
        dispatch({
            type: 'TOGGLE_RANGES_VIEW_PROPERTY',
            payload: { key: 'showIntegrals' },
        });
    }
    function handleShowJGraph() {
        dispatch({
            type: 'TOGGLE_RANGES_VIEW_PROPERTY',
            payload: { key: 'showJGraph' },
        });
    }
    const { rawWriteWithType, shouldFallback, cleanShouldFallback, text } = useClipboard();
    function saveToClipboardHandler(value) {
        void rawWriteWithType(value, 'text/html').then(() => alert.success('Data copied to clipboard'));
    }
    function saveAsHTMLHandler() {
        if (Array.isArray(ranges?.values) && ranges.values.length > 0) {
            const { originFrequency: observedFrequency, nucleus } = info;
            const result = rangesToACS(ranges.values, {
                nucleus, // '19f'
                deltaFormat: rangesPreferences.deltaPPM.format,
                couplingFormat: rangesPreferences.coupling.format,
                observedFrequency, //400
            });
            modal.show(_jsx(CopyClipboardModal, { text: result, onCopyClick: saveToClipboardHandler, onClose: () => modal.close() }), {});
        }
    }
    function changeSumConstantFlagHandler() {
        dispatch({
            type: 'CHANGE_RANGES_SUM_FLAG',
        });
    }
    function toggleViewProperty(key) {
        dispatch({ type: 'TOGGLE_RANGES_VIEW_PROPERTY', payload: { key } });
    }
    function toggleDisplayingMode() {
        dispatch({ type: 'TOGGLE_RANGES_PEAKS_DISPLAYING_MODE' });
    }
    const hasRanges = Array.isArray(ranges?.values) && ranges.values.length > 0;
    const counter = ranges?.values?.length || 0;
    return (_jsxs("div", { children: [_jsx(DefaultPanelHeader, { counter: counter, counterLabel: createFilterLabel(counter, isFilterActive && filterCounter), onDelete: handleDeleteAll, deleteToolTip: "Delete All Ranges", onFilter: onFilterActivated, filterToolTip: isFilterActive ? 'Show all ranges' : 'Hide ranges out of view', showSettingButton: true, onSettingClick: onSettingClick, children: _jsxs(Toolbar, { children: [_jsx(Toolbar.Item, { disabled: !hasRanges, icon: _jsx(FaFileExport, {}), title: "Preview publication string", onClick: saveAsHTMLHandler }), _jsx(ChangeSumModal, { onSave: changeRangesSumHandler, sumType: "ranges", currentSum: currentSum, sumOptions: ranges?.options }), _jsx(Toolbar.Item, { disabled: !hasRanges, icon: _jsx(FaUnlink, {}), title: "Remove all assignments", onClick: handleOnRemoveAssignments }), _jsx(Toolbar.Item, { disabled: !hasRanges, icon: _jsx(FaSitemap, {}), title: showMultiplicityTrees
                                ? 'Hide multiplicity trees in spectrum'
                                : 'Show multiplicity trees in spectrum', onClick: handleSetShowMultiplicityTrees, active: showMultiplicityTrees }), _jsx(Toolbar.Item, { disabled: !hasRanges, icon: _jsx(FaChartBar, {}), title: showJGraph ? 'Hide J Graph' : 'Show J Graph', onClick: handleShowJGraph, active: showJGraph }), _jsx(Toolbar.Item, { disabled: !hasRanges, icon: _jsx(SvgNmrIntegrate, {}), title: showIntegrals ? 'Hide integrals' : 'Show integrals', onClick: handleShowIntegrals, active: showIntegrals }), _jsx(Toolbar.Item, { disabled: !hasRanges, icon: _jsx(SvgNmrIntegrate, {}), title: showIntegralsValues
                                ? 'Hide integrals values'
                                : 'Show integrals values', onClick: handleShowIntegralsValues, active: showIntegralsValues }), _jsx(Toolbar.Item, { icon: _jsx(ImLink, {}), title: "Fixed integration sum", onClick: changeSumConstantFlagHandler, active: ranges?.options?.isSumConstant }), _jsx(PeaksToggleActions, { disabled: !hasRanges, togglePeaksId: "ranges-toggle-peaks", togglePeaks: showPeaks, onShowToggle: () => toggleViewProperty('showPeaks'), toggleDisplayingMode: displayingMode, onDisplayingModeToggle: toggleDisplayingMode })] }) }), _jsx(ClipboardFallbackModal, { mode: shouldFallback, onDismiss: cleanShouldFallback, text: text, label: "Preview publication string" })] }));
}
export default RangesHeader;
